# AUTO GENERATED FILE - DO NOT EDIT

import typing  # noqa: F401

from dash.development.base_component import Component, _explicitize_args
from typing_extensions import Literal, NotRequired, TypedDict  # noqa: F401

ComponentSingleType = typing.Union[str, int, float, Component, None]
ComponentType = typing.Union[
    ComponentSingleType,
    typing.Sequence[ComponentSingleType],
]

NumberType = typing.Union[typing.SupportsFloat, typing.SupportsInt, typing.SupportsComplex]


class AntdCustomSkeleton(Component):
    """An AntdCustomSkeleton component.
    自定义骨架屏组件AntdCustomSkeleton

    Keyword arguments:

    - id (string; optional):
        组件唯一id.

    - key (string; optional):
        对当前组件的`key`值进行更新，可实现强制重绘当前组件的效果.

    - children (a list of or a singular dash component, string or number; optional):
        组件型，内嵌元素.

    - className (string | dict; optional):
        当前组件css类名，支持[动态css](/advanced-classname).

    - skeletonContent (a list of or a singular dash component, string or number; optional):
        组件型，加载状态下显示的内容.

    - loading (boolean; default False):
        是否处于加载中状态.

    - delay (number; optional):
        加载动画渲染延时，单位：毫秒 默认值：`0`.

    - debug (boolean; default False):
        是否开启debug模式，开启后，每次动画加载都会在开发者工具的控制台打印相关`prop`信息 默认值：`False`.

    - listenPropsMode (a value equal to: 'default', 'exclude', 'include'; default 'default'):
        监听模式，可选项有`'default'`、`'exclude'`、`'include'` 默认值：`'default'`.

    - excludeProps (list of strings; optional):
        `listenPropsMode='exclude'`时，设置需要排除监听的回调目标列表，格式如`['组件id1.组件属性1',
        '组件id2.组件属性2', ...]`.

    - includeProps (list of strings; optional):
        `listenPropsMode='include'`时，设置需要包含监听的回调目标列表，格式如`['组件id1.组件属性1',
        '组件id2.组件属性2', ...]`.

    - manual (boolean; default False):
        是否开启手动控制模式，开启后是否处于加载状态将由`loading`参数控制，与内部元素参与的回调状态无关 默认值：`False`.

    - data-* (string; optional):
        `data-*`格式属性通配.

    - aria-* (string; optional):
        `aria-*`格式属性通配."""

    _children_props: typing.List[str] = ['skeletonContent']
    _base_nodes = ['skeletonContent', 'children']
    _namespace = 'feffery_antd_components'
    _type = 'AntdCustomSkeleton'

    def __init__(
        self,
        children: typing.Optional[ComponentType] = None,
        id: typing.Optional[typing.Union[str, dict]] = None,
        key: typing.Optional[str] = None,
        style: typing.Optional[typing.Any] = None,
        className: typing.Optional[typing.Union[str, dict]] = None,
        skeletonContent: typing.Optional[ComponentType] = None,
        loading: typing.Optional[bool] = None,
        delay: typing.Optional[NumberType] = None,
        debug: typing.Optional[bool] = None,
        listenPropsMode: typing.Optional[Literal['default', 'exclude', 'include']] = None,
        excludeProps: typing.Optional[typing.Sequence[str]] = None,
        includeProps: typing.Optional[typing.Sequence[str]] = None,
        manual: typing.Optional[bool] = None,
        **kwargs,
    ):
        self._prop_names = [
            'id',
            'key',
            'children',
            'style',
            'className',
            'skeletonContent',
            'loading',
            'delay',
            'debug',
            'listenPropsMode',
            'excludeProps',
            'includeProps',
            'manual',
            'data-*',
            'aria-*',
        ]
        self._valid_wildcard_attributes = ['data-', 'aria-']
        self.available_properties = [
            'id',
            'key',
            'children',
            'style',
            'className',
            'skeletonContent',
            'loading',
            'delay',
            'debug',
            'listenPropsMode',
            'excludeProps',
            'includeProps',
            'manual',
            'data-*',
            'aria-*',
        ]
        self.available_wildcard_properties = ['data-', 'aria-']
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        super(AntdCustomSkeleton, self).__init__(children=children, **args)


setattr(AntdCustomSkeleton, '__init__', _explicitize_args(AntdCustomSkeleton.__init__))
